@@ -2,11 +2,7 @@
 #include <stdint.h>
 #include <stddef.h>
 #include <cstring>
-
-#ifndef likely
-#  define likely(x)   __builtin_expect((x),1)
-#  define unlikely(x) __builtin_expect((x),0)
-#endif
+#include <panda/lib/def.h>
 
 namespace panda { namespace lib {
 
