@@ -137,6 +137,7 @@ struct ObjectAllocator {
     ObjectAllocator ();
 
     void* alloc (size_t size) {
+        if (size == 0) return NULL;
         MemoryPool* pool;
         if (size <= 1024) {
             pool = small_pools[(size-1)>>2];
@@ -154,6 +155,7 @@ struct ObjectAllocator {
     }
 
     void dealloc (void* ptr, size_t size) {
+        if (ptr == NULL || size == 0) return;
         MemoryPool* pool;
         if (size <= 1024) pool = small_pools[(size-1)>>2];
         else if (size <= 16384) pool = medium_pools[(size-1)>>6];
