@@ -389,6 +389,8 @@ private:
 inline string operator+ (const string& lhs, const string& rhs) { return string(lhs).append(rhs); }
 inline string operator+ (const string& lhs, const char*   rhs) { return string(lhs).append(rhs); }
 inline string operator+ (const char*   lhs, const string& rhs) { return string(rhs).insert(0, lhs); }
+inline string operator+ (const string& lhs, char*         rhs) { return string(lhs).append(rhs); }
+inline string operator+ (char*         lhs, const string& rhs) { return string(rhs).insert(0, lhs); }
 inline string operator+ (const string& lhs, char          rhs) { return string(lhs).append(1, rhs); }
 inline string operator+ (char          lhs, const string& rhs) { return string(rhs).insert(0, 1, lhs); }
 
